@@ -4,15 +4,16 @@ from .google_trans import GoogleTranslator
 from .pons import PonsTranslator
 from .linguee import LingueeTranslator
 from .mymemory import MyMemoryTranslator
-from .detection import detect_language
+from .detection import single_detection, batch_detection
 
 
 __author__ = """Nidhal Baccouri"""
 __email__ = 'nidhalbacc@gmail.com'
-__version__ = '1.1.6'
+__version__ = '1.1.7'
 
 __all__ = [GoogleTranslator,
            PonsTranslator,
            LingueeTranslator,
            MyMemoryTranslator,
-           detect_language]
+           single_detection,
+           batch_detection]
