@@ -1,5 +1,5 @@
 from deep_translator.constants import BASE_URLS, LINGUEE_LANGUAGES_TO_CODES, LINGUEE_CODE_TO_LANGUAGE
-from deep_translator.exceptions import LanguageNotSupportedException, ElementNotFoundInGetRequest, NotValidPayload, NotValidLength
+from deep_translator.exceptions import LanguageNotSupportedException, TranslationNotFound, NotValidPayload, ElementNotFoundInGetRequest
 from deep_translator.parent import BaseTranslator
 from bs4 import BeautifulSoup
 import requests
@@ -72,6 +72,9 @@ class LingueeTranslator(BaseTranslator):
                     pronoun = ''
                 filtered_elements.append(el.get_text(strip=True).replace(pronoun, ''))
 
+            if not filtered_elements:
+                raise TranslationNotFound(word)
+
             return filtered_elements if return_all else filtered_elements[0]
 
     def translate_words(self, words, **kwargs):
